==> members-facade-1.0.2-20190320.072122-61-sources.jar: com/bizvane/members/facade/models/po/MbrLevelRecordPO.java <==
package com.bizvane.members.facade.models.po;

import java.io.Serializable;
import java.util.Date;

public class MbrLevelRecordPO implements Serializable {

	/**
	 * 只读. 主键id. mbr_level_trace_id
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	@io.swagger.annotations.ApiModelProperty(value = "主键id", name = "mbrLevelTraceId", required = false, example = "")
	private Long mbrLevelTraceId;
	/**
	 * 只读. 企业id. sys_company_id
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	@io.swagger.annotations.ApiModelProperty(value = "企业id", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;
	/**
	 * 只读. . brand_id
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "brandId", required = false, example = "")
	private Long brandId;
	/**
	 * 只读. 公众号id. public_id
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	@io.swagger.annotations.ApiModelProperty(value = "公众号id", name = "publicId", required = false, example = "")
	private Long publicId;
	/**
	 * 只读. 会员编号. member_code
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员编号", name = "memberCode", required = false, example = "")
	private String memberCode;
	/**
	 * 只读. 原等级. origin_level_id
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	@io.swagger.annotations.ApiModelProperty(value = "原等级", name = "originLevelId", required = false, example = "")
	private Long originLevelId;
	/**
	 * 只读. 当前等级. current_level_id
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	@io.swagger.annotations.ApiModelProperty(value = "当前等级", name = "currentLevelId", required = false, example = "")
	private Long currentLevelId;
	/**
	 * 只读. 流水条件. conditions
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	@io.swagger.annotations.ApiModelProperty(value = "流水条件", name = "conditions", required = false, example = "")
	private String conditions;
	/**
	 * 只读. 1成功0失败. result_flag
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	@io.swagger.annotations.ApiModelProperty(value = "1成功0失败", name = "resultFlag", required = false, example = "")
	private Integer resultFlag;
	/**
	 * 只读. 线下结果1成功0失败. offline_flag
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	@io.swagger.annotations.ApiModelProperty(value = "线下结果1成功0失败", name = "offlineFlag", required = false, example = "")
	private Integer offlineFlag;
	/**
	 * 只读. 线上1成功0失败. online_flag
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	@io.swagger.annotations.ApiModelProperty(value = "线上1成功0失败", name = "onlineFlag", required = false, example = "")
	private Integer onlineFlag;
	/**
	 * 只读. 失败原因. reason
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	@io.swagger.annotations.ApiModelProperty(value = "失败原因", name = "reason", required = false, example = "")
	private String reason;
	/**
	 * 只读. 数据有效性：1=有效；0=无效. valid
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	@io.swagger.annotations.ApiModelProperty(value = "数据有效性：1=有效；0=无效", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. 备注. remark
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	@io.swagger.annotations.ApiModelProperty(value = "备注", name = "remark", required = false, example = "")
	private String remark;
	/**
	 * 只读. 创建人id. create_user_id
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. 创建人. create_user_name
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. 创建日期. create_date
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建日期", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. 修改人id. modified_user_id
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
	private Long modifiedUserId;
	/**
	 * 只读. 修改人. modified_user_name
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人", name = "modifiedUserName", required = false, example = "")
	private String modifiedUserName;
	/**
	 * 只读. 修改时间. modified_date
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改时间", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. 版本号. version
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	@io.swagger.annotations.ApiModelProperty(value = "版本号", name = "version", required = false, example = "")
	private Integer version;
	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public Long getMbrLevelTraceId() {
		return mbrLevelTraceId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public void setMbrLevelTraceId(Long mbrLevelTraceId) {
		this.mbrLevelTraceId = mbrLevelTraceId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public Long getBrandId() {
		return brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public void setBrandId(Long brandId) {
		this.brandId = brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public Long getPublicId() {
		return publicId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public void setPublicId(Long publicId) {
		this.publicId = publicId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public String getMemberCode() {
		return memberCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public void setMemberCode(String memberCode) {
		this.memberCode = memberCode == null ? null : memberCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public Long getOriginLevelId() {
		return originLevelId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public void setOriginLevelId(Long originLevelId) {
		this.originLevelId = originLevelId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public Long getCurrentLevelId() {
		return currentLevelId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public void setCurrentLevelId(Long currentLevelId) {
		this.currentLevelId = currentLevelId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public String getConditions() {
		return conditions;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public void setConditions(String conditions) {
		this.conditions = conditions == null ? null : conditions.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public Integer getResultFlag() {
		return resultFlag;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public void setResultFlag(Integer resultFlag) {
		this.resultFlag = resultFlag;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public Integer getOfflineFlag() {
		return offlineFlag;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public void setOfflineFlag(Integer offlineFlag) {
		this.offlineFlag = offlineFlag;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public Integer getOnlineFlag() {
		return onlineFlag;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public void setOnlineFlag(Integer onlineFlag) {
		this.onlineFlag = onlineFlag;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public String getReason() {
		return reason;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public void setReason(String reason) {
		this.reason = reason == null ? null : reason.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public String getRemark() {
		return remark;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public void setRemark(String remark) {
		this.remark = remark == null ? null : remark.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public Long getModifiedUserId() {
		return modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public void setModifiedUserId(Long modifiedUserId) {
		this.modifiedUserId = modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public String getModifiedUserName() {
		return modifiedUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public void setModifiedUserName(String modifiedUserName) {
		this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public Integer getVersion() {
		return version;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-15 10:23:45
	 */
	public void setVersion(Integer version) {
		this.version = version;
	}
}

==> members-facade-1.0.2-20190814.130751-231-sources.jar: com/bizvane/members/facade/models/po/MbrLevelRecordPO.java <==
package com.bizvane.members.facade.models.po;

import java.io.Serializable;
import java.util.Date;

public class MbrLevelRecordPO implements Serializable {

	/**
	 * 只读. 主键id. mbr_level_trace_id
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "主键id", name = "mbrLevelTraceId", required = false, example = "")
	private Long mbrLevelTraceId;
	/**
	 * 只读. 企业id. sys_company_id
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "企业id", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;
	/**
	 * 只读. 品牌id. brand_id
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "品牌id", name = "brandId", required = false, example = "")
	private Long brandId;
	/**
	 * 只读. 公众号id. public_id
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "公众号id", name = "publicId", required = false, example = "")
	private Long publicId;
	/**
	 * 只读. 会员编号. member_code
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员编号", name = "memberCode", required = false, example = "")
	private String memberCode;
	/**
	 * 只读. 原等级. origin_level_id
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "原等级", name = "originLevelId", required = false, example = "")
	private Long originLevelId;
	/**
	 * 只读. 当前等级. current_level_id
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "当前等级", name = "currentLevelId", required = false, example = "")
	private Long currentLevelId;
	/**
	 * 只读. 流水条件. conditions
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "流水条件", name = "conditions", required = false, example = "")
	private String conditions;
	/**
	 * 只读. 1成功0失败. result_flag
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "1成功0失败", name = "resultFlag", required = false, example = "")
	private Integer resultFlag;
	/**
	 * 只读. 线下结果1成功0失败. offline_flag
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "线下结果1成功0失败", name = "offlineFlag", required = false, example = "")
	private Integer offlineFlag;
	/**
	 * 只读. 线上1成功0失败. online_flag
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "线上1成功0失败", name = "onlineFlag", required = false, example = "")
	private Integer onlineFlag;
	/**
	 * 只读. 失败原因. reason
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "失败原因", name = "reason", required = false, example = "")
	private String reason;
	/**
	 * 只读. 操作类型 1升级 2降级. ops_type
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "操作类型 1升级 2降级", name = "opsType", required = false, example = "")
	private Integer opsType;
	/**
	 * 只读. 核准等级记录Id. mbr_check_grade_record
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "核准等级记录Id", name = "mbrCheckGradeRecord", required = false, example = "")
	private Long mbrCheckGradeRecord;
	/**
	 * 只读. 数据有效性：1=有效；0=无效. valid
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "数据有效性：1=有效；0=无效", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. 备注. remark
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "备注", name = "remark", required = false, example = "")
	private String remark;
	/**
	 * 只读. 创建人id. create_user_id
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. 创建人. create_user_name
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. 创建日期. create_date
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建日期", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. 修改人id. modified_user_id
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
	private Long modifiedUserId;
	/**
	 * 只读. 修改人. modified_user_name
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人", name = "modifiedUserName", required = false, example = "")
	private String modifiedUserName;
	/**
	 * 只读. 修改时间. modified_date
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改时间", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. 版本号. version
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	@io.swagger.annotations.ApiModelProperty(value = "版本号", name = "version", required = false, example = "")
	private Integer version;
	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public Long getMbrLevelTraceId() {
		return mbrLevelTraceId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setMbrLevelTraceId(Long mbrLevelTraceId) {
		this.mbrLevelTraceId = mbrLevelTraceId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public Long getBrandId() {
		return brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setBrandId(Long brandId) {
		this.brandId = brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public Long getPublicId() {
		return publicId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setPublicId(Long publicId) {
		this.publicId = publicId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public String getMemberCode() {
		return memberCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setMemberCode(String memberCode) {
		this.memberCode = memberCode == null ? null : memberCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public Long getOriginLevelId() {
		return originLevelId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setOriginLevelId(Long originLevelId) {
		this.originLevelId = originLevelId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public Long getCurrentLevelId() {
		return currentLevelId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setCurrentLevelId(Long currentLevelId) {
		this.currentLevelId = currentLevelId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public String getConditions() {
		return conditions;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setConditions(String conditions) {
		this.conditions = conditions == null ? null : conditions.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public Integer getResultFlag() {
		return resultFlag;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setResultFlag(Integer resultFlag) {
		this.resultFlag = resultFlag;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public Integer getOfflineFlag() {
		return offlineFlag;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setOfflineFlag(Integer offlineFlag) {
		this.offlineFlag = offlineFlag;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public Integer getOnlineFlag() {
		return onlineFlag;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setOnlineFlag(Integer onlineFlag) {
		this.onlineFlag = onlineFlag;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public String getReason() {
		return reason;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setReason(String reason) {
		this.reason = reason == null ? null : reason.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public Integer getOpsType() {
		return opsType;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setOpsType(Integer opsType) {
		this.opsType = opsType;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public Long getMbrCheckGradeRecord() {
		return mbrCheckGradeRecord;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setMbrCheckGradeRecord(Long mbrCheckGradeRecord) {
		this.mbrCheckGradeRecord = mbrCheckGradeRecord;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public String getRemark() {
		return remark;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setRemark(String remark) {
		this.remark = remark == null ? null : remark.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public Long getModifiedUserId() {
		return modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setModifiedUserId(Long modifiedUserId) {
		this.modifiedUserId = modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public String getModifiedUserName() {
		return modifiedUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setModifiedUserName(String modifiedUserName) {
		this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public Integer getVersion() {
		return version;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-21 15:31:46
	 */
	public void setVersion(Integer version) {
		this.version = version;
	}
}
